@@ -19,8 +19,8 @@
 // ========================================================================
 //
 // File          : $RCSfile: biff.cc,v $
-// Revision      : $Revision: 1.42 $
-// Revision date : $Date: 2005/04/01 13:24:49 $
+// Revision      : $Revision: 1.44 $
+// Revision date : $Date: 2005/04/07 14:46:52 $
 // Author(s)     : Nicolas Rougier
 // Short         : 
 //
@@ -52,14 +52,16 @@
 #include "file.h"
 #include "maildir.h"
 #include "mh.h"
+#include "mh_basic.h"
+#include "mh_sylpheed.h"
 #include "imap4.h"
 #include "pop3.h"
 #include "apop.h"
 
 
-// ================================================================================
+// ============================================================================
 //  "C" binding
-// ================================================================================
+// ============================================================================
 extern "C" {
 	void BIFF_xml_start_element (GMarkupParseContext *context,
 								 const gchar *element_name,
@@ -716,6 +718,12 @@ Biff::xml_end_element (GMarkupParseContext *context,
 		case PROTOCOL_MH:
 			mailbox_.push_back (new Mh (this));
 			break;
+		case PROTOCOL_MH_BASIC:
+			mailbox_.push_back (new Mh_Basic (this));
+			break;
+		case PROTOCOL_MH_SYLPHEED:
+			mailbox_.push_back (new Mh_Sylpheed (this));
+			break;
 		case PROTOCOL_MAILDIR:
 			mailbox_.push_back (new Maildir (this));
 			break;
