@@ -19,8 +19,8 @@
 // ========================================================================
 //
 // File          : $RCSfile: gnubiff_options.cc,v $
-// Revision      : $Revision: 1.28 $
-// Revision date : $Date: 2005/03/31 11:22:07 $
+// Revision      : $Revision: 1.31 $
+// Revision date : $Date: 2005/06/23 17:31:43 $
 // Author(s)     : Robert Sowada, Nicolas Rougier
 // Short         : Options for gnubiff
 //
@@ -34,10 +34,12 @@
 
 const guint Gnubiff_Options::protocol_int[] = {
 	PROTOCOL_NONE, PROTOCOL_FILE, PROTOCOL_POP3, PROTOCOL_IMAP4,
-	PROTOCOL_MAILDIR, PROTOCOL_MH, PROTOCOL_APOP, 0
+	PROTOCOL_MAILDIR, PROTOCOL_MH, PROTOCOL_APOP, PROTOCOL_MH_BASIC,
+	PROTOCOL_MH_SYLPHEED, 0
 };
 const gchar *Gnubiff_Options::protocol_gchar[] = {
-	"-", "file", "pop3", "imap4", "maildir", "mh", "apop", NULL
+	"-", "file", "pop3", "imap4", "maildir", "mh", "apop", "mhbasic",
+	"sylpheed", NULL
 };
 
 /**
@@ -408,14 +410,14 @@ Gnubiff_Options::add_options_mailbox (void)
 	add_option (new Option_UInt ("other_port", OPTGRP_MAILBOX,
 		"Port to be used when connecting to the server via the internet on "
 		"a non standard port.",
-								   995, OPTFLG_CHANGE, OPTGUI_SPIN,
+								   0, OPTFLG_CHANGE, OPTGUI_SPIN,
 								   "port_spin"));
 	// PORT
 	add_option (new Option_UInt ("port", OPTGRP_MAILBOX,
 		"Port to be used when connecting to the server via the internet. "
 		"If authentication is set to autodetect this option will be set "
 		"when the mailbox is connected for the first time.",
-								 995, OPTFLG_AUTO | OPTFLG_NOSAVE));
+								 0, OPTFLG_AUTO | OPTFLG_NOSAVE));
 	// PROTOCOL
 	add_option (new Option_UInt ("protocol", OPTGRP_MAILBOX,
 		"Protocol to be used by the mailbox.",
