@@ -1,6 +1,6 @@
 // ========================================================================
 // gnubiff -- a mail notification program
-// Copyright (c) 2000-2004 Nicolas Rougier
+// Copyright (c) 2000-2005 Nicolas Rougier
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License as
@@ -19,8 +19,8 @@
 // ========================================================================
 //
 // File          : $RCSfile: local.h,v $
-// Revision      : $Revision: 1.1 $
-// Revision date : $Date: 2004/12/03 17:16:58 $
+// Revision      : $Revision: 1.7 $
+// Revision date : $Date: 2005/04/13 12:01:03 $
 // Author(s)     : Nicolas Rougier
 // Short         : 
 //
@@ -34,10 +34,13 @@
 
 #include "mailbox.h"
 #include <fam.h>
+#include <string>
 
 #define LOCAL(x)					((Local *)(x))
 
-
+/**
+ *  Base class for all local mailbox protocols.
+ */
 class Local : public Mailbox {
 
 protected:
@@ -51,16 +54,35 @@ protected:
 public:
 	// ========================================================================
 	//  base
-	// ========================================================================	
+	// ========================================================================
 	Local (class Biff *biff);
 	Local (const Mailbox &other);
 	virtual ~Local (void);
 
+	// ========================================================================
+	//  exceptions
+	// ========================================================================
+	/** Generic exception for local mailboxes serving as a base for more
+	 *  specific exceptions. */
+	class local_err : public mailbox_err {};
+	/// Exception for a problem with the file alteration monitor (FAM).
+	class local_fam_err : public local_err {};
+	/// Exception for a problem when opening or reading a file
+	class local_file_err : public local_err {};
+	/** This exception should be thrown if there is a problem when obtaining
+	 *  information that is necessary to get and parse the messages (e.g. if
+	 *  no message sequence numbers can be obtained). */
+	class local_info_err : public local_err {};
+
 	// ========================================================================
 	//  main
-	// ========================================================================	
+	// ========================================================================
 	void start (void);								// start method
+	void fam_monitoring (void) throw (local_err);
 	void stop (void);								// stop method
+	virtual std::string file_to_monitor (void);
+	void parse_single_message_file (const std::string &filename,
+				const std::string uid = std::string ("")) throw (local_err);
 };
 
 #endif
