@@ -1,6 +1,6 @@
 // ========================================================================
 // gnubiff -- a mail notification program
-// Copyright (c) 2000-2004 Nicolas Rougier
+// Copyright (c) 2000-2005 Nicolas Rougier
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License as
@@ -19,8 +19,8 @@
 // ========================================================================
 //
 // File          : $RCSfile: mh.h,v $
-// Revision      : $Revision: 1.2 $
-// Revision date : $Date: 2004/12/03 17:13:39 $
+// Revision      : $Revision: 1.7 $
+// Revision date : $Date: 2005/04/13 12:01:03 $
 // Author(s)     : Nicolas Rougier
 // Short         : 
 //
@@ -32,27 +32,29 @@
 #ifndef __MH_H__
 #define __MH_H__
 
-#include "local.h"
+#include <glib.h>
+#include <vector>
+#include "mh_basic.h"
 
 
-class Mh : public Local {
+class Mh : public Mh_Basic {
 
 protected:
-	std::vector<guint> 		saved_;			// saved uild's
 
 public:
 	// ========================================================================
 	//  base
-	// ========================================================================	
+	// ========================================================================
 	Mh (class Biff *biff);
 	Mh (const Mailbox &other);
 	~Mh (void);
 
 	// ========================================================================
 	//  main
-	// ========================================================================	
-	int connect (void);
-	void fetch (void);
+	// ========================================================================
+	void get_messagenumbers (std::vector<guint> &msn,
+							 gboolean empty = true) throw (local_err);
+	std::string file_to_monitor (void);
 };
 
 #endif
