@@ -19,10 +19,10 @@
 // ========================================================================
 //
 // File          : $RCSfile: support.cc,v $
-// Revision      : $Revision: 1.16 $
-// Revision date : $Date: 2005/03/31 16:05:18 $
+// Revision      : $Revision: 1.21 $
+// Revision date : $Date: 2005/06/10 20:34:57 $
 // Author(s)     : Nicolas Rougier, Robert Sowada
-// Short         : Functions that should be present in glib;-)
+// Short         : Support functions
 //
 // This file is part of gnubiff.
 //
@@ -36,6 +36,7 @@
 #include <sstream>
 #include <string>
 #include <vector>
+#include "support.h"
 
 /** 
  * Duplicates the first {\em n} characters of a valid utf-8 character array,
@@ -50,7 +51,7 @@
  *              characters of {\em str}, nul-terminated
  */
 gchar* 
-gb_utf8_strndup (const gchar *str, gsize n)
+Support::utf8_strndup (const gchar *str, gsize n)
 {
     // No String
 	if (str == NULL)
@@ -89,15 +90,15 @@ gb_utf8_strndup (const gchar *str, gsize n)
  *                  substituted
  */
 std::string 
-gb_substitute(std::string format, std::string chars,
-			  std::vector<std::string> toinsert)
+Support::substitute(std::string format, std::string chars,
+					std::vector<std::string> toinsert)
 {
 	std::string::size_type pos = 0, cpos, prevpos=0;
 	std::string::size_type len = format.length();
 	std::string result("");
 
-	while ((pos < len) && (pos=format.find("%",prevpos)) != std::string::npos)
-    {
+	while ((pos < len)
+		   && (pos = format.find("%", prevpos)) != std::string::npos) {
 		if (prevpos < pos)
 			result.append (format, prevpos, pos-prevpos);
 		prevpos = pos+2;
@@ -122,6 +123,152 @@ gb_substitute(std::string format, std::string chars,
 	return result;
 }
 
+/**
+ *  Convert sequence of strictly positive numbers (given as a string) into a
+ *  vector. The sequence is to be given as a {\em sep} separated list of
+ *  numbers and ranges of numbers.  Whitespace and newline characters are
+ *  ignored (unless the {\em sep} or {\em range} are such a character).
+ *
+ *  Example: "1, 5, 6-9, 12, 4-1, 3, 5" gives [1,5,6,7,8,9,12,3,5]
+ *
+ *  @param  seq    List of numbers and ranges to convert
+ *  @param  vec    Vector in which the numbers of the sequence are returned
+ *                 if the return value is true, otherwise the value of
+ *                 {\em vec} will be undetermined
+ *  @param  empty  If true the vector will be cleared before parsing the
+ *                 sequence (the default is true)
+ *  @param  sep    Character to be used for separating list entries (default
+ *                 is ',')
+ *  @param  range  Character to be used for ranges (default is '-')
+ *  @return        Boolean indicating success
+ */
+gboolean 
+Support::numbersequence_to_vector (const std::string &seq,
+								   std::vector<guint> &vec, gboolean empty,
+								   char sep, char range)
+{
+	std::string::size_type len = seq.length(), pos = 0;
+	guint inf_bound = 0, sup_bound = 0;
+
+	// Clear vector if wished by the user
+	if (empty)
+		vec.clear ();
+
+	while (pos < len) {
+		char c = seq[pos++];
+
+		// Got a digit?
+		if (g_ascii_isdigit (c)) {
+			// Do we already have a number?
+			if (sup_bound > 0)
+				return false;
+			// Get number
+			sup_bound = c - '0';
+			while ((pos < len) && (g_ascii_isdigit (seq[pos])))
+				sup_bound = 10*sup_bound + (seq[pos++] - '0');
+			continue;
+		}
+
+		// Range indicator?
+		if (c == range) {
+			// Test for "num-num-num" format error
+			if (inf_bound > 0)
+				return false;
+			inf_bound = sup_bound;
+			sup_bound = 0;
+			continue;
+		}
+
+		// Separator?
+		if (c == sep) {
+			// No number at all or no end of range given
+			if (sup_bound == 0)
+				return false;
+			// Convert single number to range
+			if (inf_bound == 0)
+				inf_bound = sup_bound;
+			// Add numbers to vector
+			for (guint i = inf_bound; i <= sup_bound; i++)
+				vec.push_back (i);
+			inf_bound = 0;
+			sup_bound = 0;
+			continue;
+		}
+
+		// Ignore whitespace and newlines
+		if ((c == ' ') || (c == '\t') || (c == '\n') || (c == '\r'))
+			continue;
+
+		// Other character
+		return false;
+	}
+
+	// Add last number/range
+	if (sup_bound == 0)
+		return true;
+	// Convert single number to range
+	if (inf_bound == 0)
+		inf_bound = sup_bound;
+	// Add numbers
+	for (guint i = inf_bound; i <= sup_bound; i++)
+		vec.push_back (i);
+	return true;
+}
+
+/**
+ *  Add the name of a file (or directory) to the given path {\em path}.
+ *
+ *  @param  path  Path to which {\em file} will be added.
+ *  @param  file  Name of the file (or directory) that will be added to
+ *                {\em path}.
+ *  @return       Resulting path or the empty string in case of an error.
+ */
+std::string 
+Support::add_file_to_path (const std::string &path, const std::string file)
+{
+	std::string result = std::string ("");
+	gchar *newpath = g_build_filename (path.c_str(), file.c_str(), NULL);
+	if (newpath)
+		result = std::string (newpath);
+	g_free (newpath);
+	return result;
+}
+
+/**
+ *  Return the basename of the given path {\em path}.
+ *
+ *  @param  path  Path of which the basename is to be returned.
+ *  @return       Basename of {\em path} or the empty string in case of an
+ *                error
+ */
+std::string 
+Support::path_get_basename (const std::string &path)
+{
+	std::string result = std::string ("");
+	gchar *base = g_path_get_basename (path.c_str());
+	if (base)
+		result = std::string (base);
+	g_free (base);
+	return result;
+}
+
+/**
+ *  Return the directory components of the filename {\em path}.
+ *
+ *  @param path  Path of which the directory components are to be returned
+ *  @return      Directory components of the empty string in case of an error
+ */
+std::string 
+Support::path_get_dirname (const std::string &path)
+{
+	std::string result = std::string ("");
+	gchar *dir = g_path_get_dirname (path.c_str());
+	if (dir)
+		result = std::string (dir);
+	g_free (dir);
+	return result;
+}
+
 /**
  *  An unknown internal error has been encountered. Print a message that
  *  asks the user to send a bug report. Print some additional information
@@ -132,7 +279,8 @@ gb_substitute(std::string format, std::string chars,
  *  @param func  Name of the function in which the error is
  */
 void 
-unknown_internal_error_ (const gchar *file, guint line, const gchar *func)
+Support::unknown_internal_error_ (const gchar *file, guint line,
+								  const gchar *func)
 {
 	std::stringstream ss;
 	utsname uts;
@@ -154,7 +302,7 @@ unknown_internal_error_ (const gchar *file, guint line, const gchar *func)
 	ss << "function    : " << func << "\n";
 	ss << "date        : " << __DATE__ << " " << __TIME__ << "\n";
 	ss << "gnubiff     : " << PACKAGE_VERSION << " ";
-	ss <<                     IS_CVS_VERSION ? "CVS\n" : "\n";
+	ss <<                     (IS_CVS_VERSION ? "CVS\n" : "\n");
 	ss << "\n";
 	ss << "system      : " << uts.sysname << " " << uts.release << " ";
 	ss <<                     uts.version << " " << uts.machine << "\n";
