@@ -1,6 +1,6 @@
 // ========================================================================
 // gnubiff -- a mail notification program
-// Copyright (c) 2000-2004 Nicolas Rougier
+// Copyright (c) 2000-2005 Nicolas Rougier
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License as
@@ -19,8 +19,8 @@
 // ========================================================================
 //
 // File          : $RCSfile: ui-properties.cc,v $
-// Revision      : $Revision: 1.14 $
-// Revision date : $Date: 2005/02/07 23:02:37 $
+// Revision      : $Revision: 1.18 $
+// Revision date : $Date: 2005/06/24 22:35:33 $
 // Author(s)     : Nicolas Rougier
 // Short         : 
 //
@@ -192,7 +192,7 @@ Properties::select (Mailbox *mailbox)
 	}
 
 	mailbox_ = mailbox;
-	selected_auth_ = AUTH_NONE;
+	selected_auth_ = mailbox->authentication();
 	selected_type_ = -1;
 	update_view ();
 }
@@ -260,8 +260,8 @@ Properties::on_type_changed (GtkAction *action)
 		selected_type_ = TYPE_POP;
 		identity_view (true);
 		details_view (true);
-		connection_view (true);
 		auth_view (true);
+		connection_view (true);
 		certificate_view (false);
 		mailbox_view (false);
 		delay_view (true);
@@ -271,8 +271,8 @@ Properties::on_type_changed (GtkAction *action)
 		selected_type_ = TYPE_IMAP;
 		identity_view (true);
 		details_view (true);
-		connection_view (true);
 		auth_view (true);
+		connection_view (true);
 		certificate_view (false);
 		mailbox_view (true);
 		delay_view (true);
@@ -308,6 +308,9 @@ Properties::on_auth_changed (GtkAction *action)
 		selected_auth_ = AUTH_AUTODETECT;
 		certificate_view (false);
 	}
+	// Maybe the standard port has changed: Update the displayed connection
+	// details
+	connection_view (true);
 }
 
 void
@@ -363,6 +366,8 @@ Properties::on_apply (GtkWidget *widget)
 
 		if (((mailbox_->protocol() != PROTOCOL_FILE) &&
 			 (mailbox_->protocol() != PROTOCOL_MH) &&
+			 (mailbox_->protocol() != PROTOCOL_MH_BASIC) &&
+			 (mailbox_->protocol() != PROTOCOL_MH_SYLPHEED) &&
 			 (mailbox_->protocol() != PROTOCOL_MAILDIR))
 			|| (mailbox_->address() == oldaddress))
 		{
@@ -465,7 +470,6 @@ Properties::type_view (void)
 	gtk_widget_set_sensitive (get("browse_address"), true);
 	identity_view (false);
 	details_view (false);
-	connection_view (true);
 	auth_view (false);
 	certificate_view (false);
 	mailbox_view (false);
@@ -474,7 +478,10 @@ Properties::type_view (void)
 	guint protocol = mailbox_->protocol ();
 	selected_type_ = TYPE_AUTODETECT;
 
-	if ((protocol == PROTOCOL_FILE) || (protocol == PROTOCOL_MH) || (protocol == PROTOCOL_MAILDIR)) {
+	if ((protocol == PROTOCOL_FILE) || (protocol == PROTOCOL_MH)
+		|| (protocol == PROTOCOL_MH_BASIC)
+		|| (protocol == PROTOCOL_MH_SYLPHEED)
+		|| (protocol == PROTOCOL_MAILDIR)) {
 		selected_type_ = TYPE_LOCAL;
 	}
 	else if ((protocol == PROTOCOL_POP3) || (protocol == PROTOCOL_APOP)) {
@@ -495,6 +502,8 @@ Properties::type_view (void)
 		auth_view (true);
 	}
 
+	connection_view (true);
+
 	gtk_option_menu_set_history (GTK_OPTION_MENU (type_menu_), selected_type_);
 }
 
@@ -540,13 +549,29 @@ Properties::details_view (gboolean visible)
 	}
 }
 
-void
+/**
+ *  Show or hide the widgets for setting the connection port. This function
+ *  also sets the label for the standard port of the current selection.
+ *
+ *  Note: If calling several Properties::..._view(...) functions this one must
+ *  be called after Properties::auth_view(...)!
+ *
+ *  @param visible  Whether the widgets shall be visible
+ */
+void 
 Properties::connection_view (gboolean visible)
 {
+	// Show or hide the widgets
 	if (visible)
-		gtk_widget_show (get("connection_alignment"));
+		gtk_widget_show (get ("connection_alignment"));
 	else
-		gtk_widget_hide (get("connection_alignment"));
+		gtk_widget_hide (get ("connection_alignment"));
+	// Set the standard port label
+	std::stringstream ss;
+	ss << "(" << Mailbox::standard_port (selected_type_, selected_auth_, false)
+	   << ")";
+	gtk_label_set_text (GTK_LABEL (get ("label_standard_port")),
+						ss.str().c_str());
 }
 
 void
@@ -594,7 +619,7 @@ Properties::auth_view (gboolean visible)
 #ifndef HAVE_LIBSSL
 	if ((auth == AUTH_SSL) || (auth == AUTH_CERTIFICATE))
 #  ifdef HAVE_CRYPTO
-		if (selected_type == TYPE_POP)
+		if (selected_type_ == TYPE_POP)
 			auth = AUTH_APOP;
 #  else
 		auth = AUTH_USER_PASS;
